@@ -8,7 +8,7 @@ import statina
 from statina.adapter.plugin import StatinaAdapter
 from statina.config import get_nipt_adapter
 from statina.crud.insert import insert_batch, insert_samples
-from statina.models.database import Batch, DataBaseSample
+from statina.models.database import DatabaseBatch, DataBaseSample
 from statina.models.server.load import BatchRequestBody
 from statina.parse.batch import get_batch, get_samples
 
@@ -27,7 +27,7 @@ def batch(
         response.status_code = status.HTTP_422_UNPROCESSABLE_ENTITY
         return {"message": "Results file missing."}
     samples: List[DataBaseSample] = get_samples(nipt_results)
-    batch: Batch = get_batch(nipt_results)
+    batch: DatabaseBatch = get_batch(nipt_results)
     if statina.crud.find.batches.batch(adapter=adapter, batch_id=batch.batch_id):
         return "batch already in database"
 
